#[non_exhaustive]pub enum Request {
SetToplevel {
output: WlOutput,
position: u32,
},
SetOverlayPanel,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SetToplevel
set the surface type as a keyboard
Set the input_panel_surface type to keyboard.
A keyboard surface is only shown when a text input is active.
SetOverlayPanel
set the surface type as an overlay panel
Set the input_panel_surface to be an overlay panel.
This is shown near the input cursor above the application window when a text input is active.
Implementations